@@ -16,8 +16,7 @@ import dnaio
 
 from tinyalign import edit_distance
 from ..utils import Merger, merge_overlapping, unique_name, is_same_gene, slice_arg
-from ..table import read_table, fix_columns
-
+from ..table import read_table, read_table_chunks
 
 logger = logging.getLogger(__name__)
 
@@ -198,18 +197,17 @@ def count_occurrences(candidates, table_path, search_columns, other_gene, other_
     candidates_map = {c.sequence: c for c in candidates}
 
     search_order = [c.sequence for c in candidates]
-    cols = [other_gene, 'V_errors', 'J_errors', 'CDR3_nt'] + search_columns
+    cols = [other_gene, 'V_errors', 'J_errors', 'cdr3'] + search_columns
 
     search_cache = defaultdict(list)  # map haystack sequence to list of candidates that occur in it
-    for chunk in pd.read_csv(table_path, usecols=cols, chunksize=10000, sep='\t'):
-        fix_columns(chunk)
+    for chunk in read_table_chunks(table_path, usecols=cols, chunksize=10000):
         if perfect_matches:
-            chunk = chunk[chunk[other_errors] == 0]
+            chunk = chunk[chunk[other_errors] == 0].copy()
         # concatenate search columns
         if len(chunk) == 0:  # TODO that this is needed is possibly a pandas bug
             continue
         chunk['haystack'] = chunk.loc[:, search_columns].astype(str).sum(axis=1)
-        chunk['haystack'] = chunk['haystack'].str.replace('(', '').replace(')', '')
+        chunk['haystack'] = chunk['haystack'].str.replace('(', '', regex=False).replace(')', '', regex=False)
 
         for row in chunk.itertuples():
             if row.haystack not in search_cache:
@@ -219,7 +217,7 @@ def count_occurrences(candidates, table_path, search_columns, other_gene, other_
             for candidate in search_cache[row.haystack]:
                 candidate.exact_occ += 1  # TODO += row.count?
                 candidate.other_genes.add(getattr(row, other_gene))
-                candidate.cdr3s.add(row.CDR3_nt)
+                candidate.cdr3s.add(row.cdr3)
                 if merge:
                     # When overlapping candidates have been merged,
                     # there will be no other pattern that is a
@@ -258,11 +256,11 @@ def sequence_candidates(table, column, minimum_length, core=slice(None, None), m
 
 
 def count_unique_cdr3(table):
-    return len(set(s for s in table.CDR3_nt if s))
+    return len(set(s for s in table.cdr3 if s))
 
 
 def count_unique_gene(table, gene_type):
-    return len(set(s for s in table[gene_type + '_gene'] if s))
+    return len(set(s for s in table[gene_type.lower() + '_call'] if s))
 
 
 def compute_expressions(table, gene_type):
@@ -272,7 +270,7 @@ def compute_expressions(table, gene_type):
     for gt in 'V', 'D', 'J':
         if gene_type != gt:
             columns += ('unique_' + gt,)
-    gene_column = gene_type + '_gene'
+    gene_column = gene_type.lower() + '_call'
     rows = []
     for gene, group in table.groupby(gene_column):
         if gene == '':
@@ -334,10 +332,10 @@ def main(args):
         database = None
     column = {'V': 'V_nt', 'J': 'J_nt', 'D': 'D_region'}[args.gene]
     other = 'V' if args.gene in ('D', 'J') else 'J'
-    other_gene = other + '_gene'
+    other_gene = other.lower() + '_call'
     other_errors = other + '_errors'
     table = read_table(args.table,
-        usecols=['count', 'V_gene', 'D_gene', 'J_gene', 'V_errors', 'J_errors', 'J_covered', column, 'CDR3_nt'])
+        usecols=['count', 'v_call', 'd_call', 'j_call', 'V_errors', 'J_errors', 'J_covered', column, 'cdr3'])
     logger.info('Table with %s rows read', len(table))
 
     if args.j_coverage is None and args.gene == 'J':
@@ -393,9 +391,9 @@ def main(args):
             merger.add(candidate)
         logger.info('After merging overlapping %s sequences, %s remain', args.gene, len(merger))
         candidates = list(merger)
+        logger.info('%d candidates', len(candidates))
     del table
 
-    logger.info('%d candidates', len(candidates))
     # Assign names etc.
     if database:
         for candidate in candidates:
@@ -431,11 +429,11 @@ def main(args):
 
     logger.info('Counting occurrences ...')
     if args.gene == 'D':
-        search_columns = ['VD_junction', 'D_region', 'DJ_junction']
+        search_columns = ['np1', 'D_region', 'np2']
     elif args.gene == 'J':
-        search_columns = ['DJ_junction', 'J_nt']
+        search_columns = ['np2', 'J_nt']
     else:
-        search_columns = ['genomic_sequence']
+        search_columns = ['sequence']
     candidates = count_occurrences(candidates, args.table, search_columns, other_gene, other_errors,
         args.merge, args.perfect_matches)
 
